@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,10 +18,36 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkcdn.endpoint import endpoint_data
+
 class StartMixStreamsServiceRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2014-11-11', 'StartMixStreamsService')
+		self.set_method('POST')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
+
+	def get_MixStreamName(self):
+		return self.get_query_params().get('MixStreamName')
+
+	def set_MixStreamName(self,MixStreamName):
+		self.add_query_param('MixStreamName',MixStreamName)
+
+	def get_MixAppName(self):
+		return self.get_query_params().get('MixAppName')
+
+	def set_MixAppName(self,MixAppName):
+		self.add_query_param('MixAppName',MixAppName)
+
+	def get_MainStreamName(self):
+		return self.get_query_params().get('MainStreamName')
+
+	def set_MainStreamName(self,MainStreamName):
+		self.add_query_param('MainStreamName',MainStreamName)
 
 	def get_MixType(self):
 		return self.get_query_params().get('MixType')
@@ -41,12 +67,6 @@ class StartMixStreamsServiceRequest(RpcRequest):
 	def set_MainDomainName(self,MainDomainName):
 		self.add_query_param('MainDomainName',MainDomainName)
 
-	def get_MixStreamName(self):
-		return self.get_query_params().get('MixStreamName')
-
-	def set_MixStreamName(self,MixStreamName):
-		self.add_query_param('MixStreamName',MixStreamName)
-
 	def get_MixTemplate(self):
 		return self.get_query_params().get('MixTemplate')
 
@@ -69,16 +89,4 @@ class StartMixStreamsServiceRequest(RpcRequest):
 		return self.get_query_params().get('MainAppName')
 
 	def set_MainAppName(self,MainAppName):
-		self.add_query_param('MainAppName',MainAppName)
-
-	def get_MixAppName(self):
-		return self.get_query_params().get('MixAppName')
-
-	def set_MixAppName(self,MixAppName):
-		self.add_query_param('MixAppName',MixAppName)
-
-	def get_MainStreamName(self):
-		return self.get_query_params().get('MainStreamName')
-
-	def set_MainStreamName(self,MainStreamName):
-		self.add_query_param('MainStreamName',MainStreamName)
\ No newline at end of file
+		self.add_query_param('MainAppName',MainAppName)
\ No newline at end of file
